## print visualization

> pypi link coming soon

==================

A lightweight python module to visualize progress and other tasks to boost your console window

==================

### features:

1. clear console
2. clear only the last line in console
3. asynchronous loading bar `[███████-------------]`
4. asynchronous loading wheel



